@@ -1294,7 +1294,7 @@ class SSHTunnelForwarder(object):
                 self._stop_transport()
 
         if self.ssh_password:  # avoid conflict using both pass and pkey
-            self.logger.debug('Logging in with password {0}'
+            self.logger.debug('Trying to log in with password: {0}'
                               .format('*' * len(self.ssh_password)))
             try:
                 self._transport = self._get_transport()
@@ -1328,8 +1328,8 @@ class SSHTunnelForwarder(object):
         """ Close the underlying transport when nothing more is needed """
         try:
             self._check_is_started()
-        except (HandlerSSHTunnelForwarderError,
-                BaseSSHTunnelForwarderError) as e:
+        except (BaseSSHTunnelForwarderError,
+                HandlerSSHTunnelForwarderError) as e:
             self.logger.warning(e)
         for _srv in self._server_list:
             tunnel = _srv.local_address
